Link - Betty 0.4.0a4 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Link

A `betty.model.ancestry.Link` adds external links to entities.

## Fields

Notes inherit from:

- Privacy

`description` (optional `str`)

  The link’s human-readable description.

`locale` (optional `str`)

  The locale of the referenced resource as an IETF BCP 47 language tag.

`label` (optional `str`)

  The human-readable label of this link, e.g. the link text.

`media_type` (MediaType)

  The media type of the referenced resource.

`relationship` (optional `str`)

  The relationship between this resource this link is set on and the link target.

`url` (`url`)

  The URL to the referenced resource.